@@ -6,10 +6,12 @@ class Crawl:
         self.downloader = Downloader()
 
     async def fetch(self,  url, params=None, data=None, files=None, json=None, content=None,headers=None, cookies=None,
-                    auth=None, proxies=None, allow_redirects=True, stream=False, timeout=30, cycle=3):
+                    verify=True, http2=False, auth=None, proxies=None, allow_redirects=True, stream=False,
+                    timeout=30, cycle=3):
         res = await self.downloader.request(
             url, params=params, data=data, files=files, json=json,content=content, headers=headers, proxies=proxies,
-            cookies=cookies, auth=auth, allow_redirects=allow_redirects, timeout=timeout, cycle=cycle, stream=stream
+            verify=verify, http2=http2, cookies=cookies, auth=auth, allow_redirects=allow_redirects, timeout=timeout,
+            cycle=cycle, stream=stream
         )
         return res
 
